==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/frame/IllegalArgumentIOException.hpp <==
#ifndef _COM_SUN_STAR_FRAME_ILLEGALARGUMENTIOEXCEPTION_HPP_
#define _COM_SUN_STAR_FRAME_ILLEGALARGUMENTIOEXCEPTION_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_FRAME_ILLEGALARGUMENTIOEXCEPTION_HDL_
#include "com/sun/star/frame/IllegalArgumentIOException.hdl"
#endif

#ifndef _COM_SUN_STAR_IO_IOEXCEPTION_HPP_
#include "com/sun/star/io/IOException.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif

namespace com { namespace sun { namespace star { namespace frame {

inline IllegalArgumentIOException::IllegalArgumentIOException() SAL_THROW( () )
    : ::com::sun::star::io::IOException()
{ }

inline IllegalArgumentIOException::IllegalArgumentIOException(const ::rtl::OUString& Message_, const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Context_) SAL_THROW( () )
    : ::com::sun::star::io::IOException(Message_, Context_)
{ }

IllegalArgumentIOException::IllegalArgumentIOException(IllegalArgumentIOException const & the_other): ::com::sun::star::io::IOException(the_other) {}

IllegalArgumentIOException::~IllegalArgumentIOException() {}

IllegalArgumentIOException & IllegalArgumentIOException::operator =(IllegalArgumentIOException const & the_other) {
    //TODO: Just like its implicitly-defined counterpart, this function definition is not exception-safe
    ::com::sun::star::io::IOException::operator =(the_other);
    return *this;
}

} } } }

inline const ::com::sun::star::uno::Type& SAL_CALL getCppuType( const ::com::sun::star::frame::IllegalArgumentIOException* ) SAL_THROW( () )
{
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_EXCEPTION, "com.sun.star.frame.IllegalArgumentIOException" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
}

#endif // _COM_SUN_STAR_FRAME_ILLEGALARGUMENTIOEXCEPTION_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/frame/IllegalArgumentIOException.hpp <==
#ifndef _COM_SUN_STAR_FRAME_ILLEGALARGUMENTIOEXCEPTION_HPP_
#define _COM_SUN_STAR_FRAME_ILLEGALARGUMENTIOEXCEPTION_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_FRAME_ILLEGALARGUMENTIOEXCEPTION_HDL_
#include "com/sun/star/frame/IllegalArgumentIOException.hdl"
#endif

#ifndef _COM_SUN_STAR_IO_IOEXCEPTION_HPP_
#include "com/sun/star/io/IOException.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif

namespace com { namespace sun { namespace star { namespace frame {

inline IllegalArgumentIOException::IllegalArgumentIOException() SAL_THROW( () )
    : ::com::sun::star::io::IOException()
{ }

inline IllegalArgumentIOException::IllegalArgumentIOException(const ::rtl::OUString& Message_, const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Context_) SAL_THROW( () )
    : ::com::sun::star::io::IOException(Message_, Context_)
{ }

IllegalArgumentIOException::IllegalArgumentIOException(IllegalArgumentIOException const & the_other): ::com::sun::star::io::IOException(the_other) {}

IllegalArgumentIOException::~IllegalArgumentIOException() {}

IllegalArgumentIOException & IllegalArgumentIOException::operator =(IllegalArgumentIOException const & the_other) {
    //TODO: Just like its implicitly-defined counterpart, this function definition is not exception-safe
    ::com::sun::star::io::IOException::operator =(the_other);
    return *this;
}

} } } }

namespace com { namespace sun { namespace star { namespace frame {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::frame::IllegalArgumentIOException const *) {
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_EXCEPTION, "com.sun.star.frame.IllegalArgumentIOException" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::frame::IllegalArgumentIOException const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::frame::IllegalArgumentIOException >::get();
}

#endif // _COM_SUN_STAR_FRAME_ILLEGALARGUMENTIOEXCEPTION_HPP_
